==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebBaseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebBaseEventArgsDescription } from "./WebBaseEventArgsDescription";
/**
 * @hidden
 */
var WebBaseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBaseEventArgsDescriptionMetadata, _super);
    function WebBaseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseEventArgsDescriptionMetadata.b = function (a) {
        if (WebBaseEventArgsDescriptionMetadata.a == null) {
            WebBaseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseEventArgsDescriptionMetadata.c(WebBaseEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebBaseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebBaseEventArgsDescriptionMetadata.a);
        WebBaseEventArgsDetailDescriptionMetadata.d(a);
    };
    WebBaseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:BaseEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebBaseEventArgsDetail");
    };
    WebBaseEventArgsDescriptionMetadata.d = function (a) {
        WebBaseEventArgsDescriptionMetadata.b(a);
        a.ad("WebBaseEventArgs", function () { return new WebBaseEventArgsDescription(); });
        a.ac("WebBaseEventArgs", WebBaseEventArgsDescriptionMetadata.a);
    };
    WebBaseEventArgsDescriptionMetadata.$t = markType(WebBaseEventArgsDescriptionMetadata, 'WebBaseEventArgsDescriptionMetadata');
    WebBaseEventArgsDescriptionMetadata.a = null;
    return WebBaseEventArgsDescriptionMetadata;
}(Base));
export { WebBaseEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebBaseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebBaseEventArgsDescription } from "./WebBaseEventArgsDescription";
/**
 * @hidden
 */
var WebBaseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBaseEventArgsDescriptionMetadata, _super);
    function WebBaseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseEventArgsDescriptionMetadata.b = function (a) {
        if (WebBaseEventArgsDescriptionMetadata.a == null) {
            WebBaseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseEventArgsDescriptionMetadata.c(WebBaseEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebBaseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebBaseEventArgsDescriptionMetadata.a);
        WebBaseEventArgsDetailDescriptionMetadata.d(a);
    };
    WebBaseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:BaseEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebBaseEventArgsDetail");
    };
    WebBaseEventArgsDescriptionMetadata.d = function (a) {
        WebBaseEventArgsDescriptionMetadata.b(a);
        a.ae("WebBaseEventArgs", function () { return new WebBaseEventArgsDescription(); });
        a.ad("WebBaseEventArgs", WebBaseEventArgsDescriptionMetadata.a);
    };
    WebBaseEventArgsDescriptionMetadata.$t = markType(WebBaseEventArgsDescriptionMetadata, 'WebBaseEventArgsDescriptionMetadata');
    WebBaseEventArgsDescriptionMetadata.a = null;
    return WebBaseEventArgsDescriptionMetadata;
}(Base));
export { WebBaseEventArgsDescriptionMetadata };
